@@ -13,12 +13,20 @@ set -e
 set -x
 set -o pipefail
 
+GOBIN=${GOBIN:-go}
+
 upstream_version="$2"
 orig_tar=$(realpath "../telegraf_${upstream_version}.orig.tar.xz")
 orig_dir="$PWD"
-work_dir="$(mktemp -d)"
+work_dir=$(mktemp -d)
 
-trap "rm -rf $workdir" INT QUIT 0
+cleanup ()
+{
+    "$GOBIN" clean -cache -modcache
+    rm -rf "$work_dir"
+}
+
+trap cleanup INT QUIT 0
 
 export GOPATH="$work_dir/.gopath"
 export GOCACHE="$work_dir/.gocache"
@@ -26,13 +34,12 @@ export GOCACHE="$work_dir/.gocache"
 printf "Unpacking tarball '$orig_tar' to '$work_dir'"
 
 tar xf "$orig_tar" -C "$work_dir"
-source_dir_name="$(ls -1 "$work_dir")"
+source_dir_name=$(ls -1 "$work_dir")
 cd "$work_dir/$source_dir_name"
-go mod vendor
+"$GOBIN" mod vendor
 cd ..
 tar cJf "$orig_tar" "$source_dir_name"
 
-go clean -cache -modcache
-rm -rf "$work_dir"
+cleanup
 
 exit 0
